@@ -1,31 +1,26 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Designer of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:GPL-EXCEPT$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3 as published by the Free Software
+** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -379,7 +374,7 @@ void SignalSlotEditor::fromUi(const DomConnections *connections, QWidget *parent
     setBackground(parent);
     clear();
     const QList<DomConnection*> list = connections->elementConnection();
-    foreach (const DomConnection *dom_con, list) {
+    for (const DomConnection *dom_con : list) {
         QObject *source = objectByName(parent, dom_con->elementSender());
         if (source == 0) {
             qDebug("SignalSlotEditor::fromUi(): no source widget called \"%s\"",
@@ -396,8 +391,8 @@ void SignalSlotEditor::fromUi(const DomConnections *connections, QWidget *parent
         QPoint sp = QPoint(20, 20), tp = QPoint(20, 20);
         const DomConnectionHints *dom_hints = dom_con->elementHints();
         if (dom_hints != 0) {
-            QList<DomConnectionHint*> list = dom_hints->elementHint();
-            foreach (DomConnectionHint *hint, list) {
+            const QList<DomConnectionHint*> &hints = dom_hints->elementHint();
+            for (DomConnectionHint *hint : hints) {
                 QString attr_type = hint->attributeType();
                 QPoint p = QPoint(hint->elementX(), hint->elementY());
                 if (attr_type == QStringLiteral("sourcelabel"))
